︠7e3da996-07cd-40a2-974e-70bc8fddf0ec︠
# A simple function to parse our data file

import os, sys
import datetime

class Record():
    def __init__(self, timestamp, kind, values):
        self.timestamp = timestamp
        self.kind = kind
        self.values = values

def parseRecord(timestamp, kind, rest):
    floats = [float(x.strip()) for x in rest.split(",")]
    r = Record(timestamp, kind, floats)
    return r
        
def parseLog(logfile):
    records = []
    with open(logfile, "r") as f:
        for l in f:
            e = l.split(":")
            r = parseRecord(float(e[0]), e[1].strip(), e[2].strip())
            records.append(r)
    return records
︡f9b9cd24-1afb-4d54-a0d3-910c3844aa8d︡︡
︠c071e798-a926-4ed4-abf0-2acb258d6ede︠
recs = parseLog(DATA+"WorkToJeffs.log")
︡75c3044d-6d61-4d85-81d2-43fa75d9bfe9︡︡
︠6ddf7e43-52ba-4fad-b3ff-f38bc7fbf087︠
# Filter out the acceleration and GPS data
acc = [r for r in recs if r.kind == "ACL"]
gps = [r for r in recs if r.kind == "LOC"]
speed = [r for r in recs if r.kind == "VEL"]
︡2a89e324-983e-48fd-a995-eb2aa44f34d6︡︡
︠d8b79168-7349-40e6-a0ec-8365f40ccfd6︠
# Sanity check
print len(acc), len(gps), len(speed)
︡786dda41-bbf0-4654-bdcb-f726db120c34︡{"stdout": "4213 153 153"}︡
︠1077f667-fee3-4acb-b013-95756870bafd︠
# Plot lateral acceleration
t=[r.timestamp for r in acc]
latAcc=[r.values[0] for r in acc]
p = list_plot(zip(t,latAcc), plotjoined=True)
p.axes_labels(["Time", "Lateral Acceleration (G's) (positive is left turn)"])
p.show()
︡081793d1-9889-4c98-a0b7-7c41f733b2e3︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠2bc9d392-1bcb-4c86-9e80-cff1ac6272fb︠
# Plot front/back acceleration
fbAcc=[r.values[1] for r in acc]
p = list_plot(zip(t,fbAcc), plotjoined=True)
p.axes_labels(["Time", "Braking/Accelerating (G's) (positive is braking)"])
p.show()
︡f0102578-1427-4ee2-8441-6470f913d96f︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠fe5d490d-a7de-41f3-9ab5-802c8a063cf5︠
# Plot a friction circle
import numpy
#title = text("Acceleration (G's)", (0,1), rgbcolor='black',fontsize=15)
guides = [circle((0,0), r, color='grey', zorder=1) for r in numpy.arange(0,.7501,.25)]
p = scatter_plot(zip(latAcc,fbAcc), edgecolor='red', facecolor='red', marker="o", markersize=4, aspect_ratio=1, axes_labels=("left turn", "braking"))
(sum(guides)+p)
︡93e23d80-a112-4e0a-a8a6-754d9d2093dd︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠391e606b-9bc1-4829-989c-a6106cf0ca8c︠
# Plot GPS location
long=[r.values[1] for r in gps]
lat=[r.values[0] for r in gps]
list_plot(zip(long,lat), plotjoined=False, aspect_ratio=1)
︡db02054f-4ec3-4d27-82d6-a50fbb72ac2a︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠09542416-3e01-4b36-9be9-a209ceed81ab︠
# Now show speed as a color along the route
locPoints = [] # [point(p) for p in zip(long, lat)]
allColors = [hue(x) for x in numpy.arange(0, 1, 1/len(lat))]
redToGreen = [(1-x,x,0) for x in numpy.arange(0, 1, 1/len(lat))]
speeds = [r.values[0] for r in speed]
maxSpeed = max(speeds)
for (x,y,s) in zip(long, lat, speeds):
    g = s/maxSpeed
    r = 1-g
    b = 0
    locPoints.append(point((x, y), color=(r,g,b)))
sum(locPoints)
︡08a41f6e-84ca-4bb2-a815-e7955935e97c︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠ab9ce5de-8afb-4fb2-bef7-1844187cad28︠
# Plot speed vs. time
x = [r.timestamp for r in speed]
y = [r.values[0] for r in speed]
# Convert to mph
y = [s*2.23693629 for s in y]
p = list_plot(zip(x,y), plotjoined=True)
p.axes_labels(["Time", "Speed (mph)"])
p.show()
︡18b8cbc1-68f3-4c2f-9730-00bc17c72408︡{"html": "<font color='black'><img src='cell://sage0.png'></font>"}︡
︠1b025f2a-0794-4151-915d-640814a6f280︠
print "Top speed was %.2f mph." % max(y)
︡e1f8be10-542d-40f3-a3d4-6a5071ef20b7︡{"stdout": "Top speed was 41.73 mph."}︡
︠3e63aa78-a018-40d4-855a-082add6caac9︠
# Sage is the shit.
︡74ce26bc-f046-4bb1-be3e-781cba01fb05︡︡
